aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gnu/packages/file-systems.scm12
1 files changed, 10 insertions, 2 deletions
diff --git a/gnu/packages/file-systems.scm b/gnu/packages/file-systems.scm
index 0499c9f755..8a2255f078 100644
--- a/gnu/packages/file-systems.scm
+++ b/gnu/packages/file-systems.scm
@@ -723,7 +723,8 @@ performance and other characteristics.")
(license license:gpl2+)))
(define-public bcachefs-tools
;; The final public package with shell completion even when cross-compiling.
(package
(inherit bcachefs-tools-minimal)
(name "bcachefs-tools")
@@ -737,6 +738,10 @@ performance and other characteristics.")
(srfi srfi-26)))
((#:phases phases #~%standard-phases)
#~(modify-phases #$phases
+ (add-before 'build 'enable-fuse
+ (lambda _
+ ;; This must be an environment variable, not a make flag!
+ (setenv "BCACHEFS_FUSE" "1")))
(add-after 'install 'install-completions
(lambda* (#:key native-inputs #:allow-other-keys)
(define bcachefs
@@ -763,7 +768,10 @@ performance and other characteristics.")
(append (package-native-inputs bcachefs-tools-minimal)
(if (%current-target-system)
(list bcachefs-tools-minimal)
- (list))))))
+ (list))))
+ (inputs
+ (modify-inputs (package-inputs bcachefs-tools-minimal)
+ (append fuse)))))
(define-public bcachefs-tools-minimal/static
;; The static variant is public for consistency with the other file system
@@ -723,7 +723,8 @@ performance and other characteristics.")
(license license:gpl2+)))
(define-public bcachefs-tools
- ;; The final public package with shell completion even when cross-compiling.
+ ;; The final public package with shell completion even when cross-compiling,
+ ;; as well as optional features such as FUSE (‘bcachefs fusemount’).
(package
(inherit bcachefs-tools-minimal)